@@ -1,14 +1,9 @@
-tv.home <- function(sysPath=FALSE) {
-  if(sysPath) tv_home <- file.path(.path.package("vegdata"), "tvdata") else
+tv.home <- function() {
   if(is.null(getOption('tv_home'))) {
     if(.Platform$OS.type == "unix") if(file.access(paste(Sys.getenv('HOME'),'/.wine/drive_c/Turbowin',sep=''))==0)
       tv_home <- file.path(Sys.getenv('HOME'),'.wine/drive_c/Turbowin') else {
-        warning('Default Turbowin installation path not found. \n
-##########################################################
-Please specify with:
-options(tv_home=\"path_to_your_ Turbowin_root\").
-##########################################################')
-	tv_home <- NULL
+        cat('\nNo Turbowin installation path found. \n')
+	tv_home <- file.path(.path.package("vegdata"), "tvdata")
 	}
     if(.Platform$OS.type == "windows") {
       if(file.access('O:/Turbowin/Popup/tvscale.dbf')==0) tv_home <- 'O:/Turbowin' else {
@@ -16,14 +11,15 @@ options(tv_home=\"path_to_your_ Turbowin_root\").
 	  if(file.access('C:/Programs/Turbowin/Popup/tvscale.dbf') ==0) tv_home <- 'C:/Programme/Turbowin' else
 	    if(file.access('C:/Programme/Turbowin/Popup/tvscale.dbf') ==0) tv_home <- 'C:/Programme/Turbowin' else
 	      if(file.access('D:/Programme/Turbowin/Popup/tvscale.dbf') ==0) tv_home <- 'D:/Programme/Turbowin' else {
-       warning('Default Turbowin installation path not found. \n
-##########################################################
-Please specify with:
-options(tv_home=\"path_to_your_ Turbowin_root\").
-##########################################################')
-	  tv_home <- NULL
+       cat('\nNo Turbowin installation path found. \n')
+	tv_home <- file.path(.path.package("vegdata"), "tvdata")
       }}}}
-    tv_home
-  } else getOption('tv_home')
+  cat('\n##########################################################',
+      '\nTurboveg root directory is set to', tv_home,
+      '\nIf you want to change this use: options(tv_home=\"<path_to_your_Turbowin_root>\")',
+      '\n##########################################################\n')
+  options(tv_home=tv_home)
+  } else tv_home <- getOption('tv_home')
+  invisible(tv_home)
 }
 
